@@ -1,16 +1,18 @@
 package syftjson
 
 import (
+	"github.com/anchore/syft/internal"
 	"github.com/anchore/syft/syft/sbom"
 )
 
-const ID sbom.FormatID = "syft-6-json"
+const ID sbom.FormatID = "syft-json"
 
 func Format() sbom.Format {
 	return sbom.NewFormat(
-		ID,
+		internal.JSONSchemaVersion,
 		encoder,
 		decoder,
 		validator,
+		ID, "json", "syft",
 	)
 }
