@@ -1,11 +1,13 @@
 package cataloger
 
 import (
+	"github.com/anchore/syft/syft/pkg/cataloger/golang"
 	"github.com/anchore/syft/syft/pkg/cataloger/java"
 )
 
 type Config struct {
 	Search      SearchConfig
+	Golang      golang.GoCatalogerOpts
 	Catalogers  []string
 	Parallelism int
 }
@@ -23,3 +25,7 @@ func (c Config) Java() java.Config {
 		SearchIndexedArchives:   c.Search.IncludeIndexedArchives,
 	}
 }
+
+func (c Config) Go() golang.GoCatalogerOpts {
+	return c.Golang
+}
