@@ -1,6 +1,7 @@
 package sbom
 
 import (
+	"bytes"
 	"io"
 )
 
@@ -16,6 +17,16 @@ func (w *streamWriter) Write(s SBOM) error {
 	return w.format.Encode(w.out, s)
 }
 
+// Bytes returns the bytes of the SBOM that would be written
+func (w *streamWriter) Bytes(s SBOM) ([]byte, error) {
+	var buffer bytes.Buffer
+	err := w.format.Encode(&buffer, s)
+	if err != nil {
+		return nil, err
+	}
+	return buffer.Bytes(), nil
+}
+
 // Close any resources, such as open files
 func (w *streamWriter) Close() error {
 	if w.close != nil {
