@@ -8,17 +8,16 @@ import (
 	"io/fs"
 	"io/ioutil"
 	"os"
-	"path"
 	"path/filepath"
-	"reflect"
+	"sort"
 	"strings"
 	"testing"
 	"time"
 
+	"github.com/google/go-cmp/cmp"
 	"github.com/scylladb/go-set/strset"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	"github.com/wagoodman/go-progress"
 
 	"github.com/anchore/stereoscope/pkg/file"
 )
@@ -57,7 +56,7 @@ func TestDirectoryResolver_FilesByPath_relativeRoot(t *testing.T) {
 	}
 	for _, c := range cases {
 		t.Run(c.name, func(t *testing.T) {
-			resolver, err := newDirectoryResolver(c.relativeRoot)
+			resolver, err := newDirectoryResolver(c.relativeRoot, "")
 			assert.NoError(t, err)
 
 			refs, err := resolver.FilesByPath(c.input)
@@ -111,7 +110,7 @@ func TestDirectoryResolver_FilesByPath_absoluteRoot(t *testing.T) {
 			absRoot, err := filepath.Abs(c.relativeRoot)
 			require.NoError(t, err)
 
-			resolver, err := newDirectoryResolver(absRoot)
+			resolver, err := newDirectoryResolver(absRoot, "")
 			assert.NoError(t, err)
 
 			refs, err := resolver.FilesByPath(c.input)
@@ -172,7 +171,7 @@ func TestDirectoryResolver_FilesByPath(t *testing.T) {
 	}
 	for _, c := range cases {
 		t.Run(c.name, func(t *testing.T) {
-			resolver, err := newDirectoryResolver(c.root)
+			resolver, err := newDirectoryResolver(c.root, "")
 			assert.NoError(t, err)
 
 			hasPath := resolver.HasPath(c.input)
@@ -220,7 +219,7 @@ func TestDirectoryResolver_MultipleFilesByPath(t *testing.T) {
 	}
 	for _, c := range cases {
 		t.Run(c.name, func(t *testing.T) {
-			resolver, err := newDirectoryResolver("./test-fixtures")
+			resolver, err := newDirectoryResolver("./test-fixtures", "")
 			assert.NoError(t, err)
 			refs, err := resolver.FilesByPath(c.input...)
 			assert.NoError(t, err)
@@ -233,7 +232,7 @@ func TestDirectoryResolver_MultipleFilesByPath(t *testing.T) {
 }
 
 func TestDirectoryResolver_FilesByGlobMultiple(t *testing.T) {
-	resolver, err := newDirectoryResolver("./test-fixtures")
+	resolver, err := newDirectoryResolver("./test-fixtures", "")
 	assert.NoError(t, err)
 	refs, err := resolver.FilesByGlob("**/image-symlinks/file*")
 	assert.NoError(t, err)
@@ -242,7 +241,7 @@ func TestDirectoryResolver_FilesByGlobMultiple(t *testing.T) {
 }
 
 func TestDirectoryResolver_FilesByGlobRecursive(t *testing.T) {
-	resolver, err := newDirectoryResolver("./test-fixtures/image-symlinks")
+	resolver, err := newDirectoryResolver("./test-fixtures/image-symlinks", "")
 	assert.NoError(t, err)
 	refs, err := resolver.FilesByGlob("**/*.txt")
 	assert.NoError(t, err)
@@ -250,7 +249,7 @@ func TestDirectoryResolver_FilesByGlobRecursive(t *testing.T) {
 }
 
 func TestDirectoryResolver_FilesByGlobSingle(t *testing.T) {
-	resolver, err := newDirectoryResolver("./test-fixtures")
+	resolver, err := newDirectoryResolver("./test-fixtures", "")
 	assert.NoError(t, err)
 	refs, err := resolver.FilesByGlob("**/image-symlinks/*1.txt")
 	assert.NoError(t, err)
@@ -277,7 +276,7 @@ func TestDirectoryResolver_FilesByPath_ResolvesSymlinks(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			resolver, err := newDirectoryResolver("./test-fixtures/symlinks-simple")
+			resolver, err := newDirectoryResolver("./test-fixtures/symlinks-simple", "")
 			assert.NoError(t, err)
 
 			refs, err := resolver.FilesByPath(test.fixture)
@@ -300,20 +299,16 @@ func TestDirectoryResolver_FilesByPath_ResolvesSymlinks(t *testing.T) {
 
 func TestDirectoryResolverDoesNotIgnoreRelativeSystemPaths(t *testing.T) {
 	// let's make certain that "dev/place" is not ignored, since it is not "/dev/place"
-	resolver, err := newDirectoryResolver("test-fixtures/system_paths/target")
+	resolver, err := newDirectoryResolver("test-fixtures/system_paths/target", "")
 	assert.NoError(t, err)
-	// ensure the correct filter function is wired up by default
-	expectedFn := reflect.ValueOf(isUnallowableFileType)
-	actualFn := reflect.ValueOf(resolver.pathFilterFns[0])
-	assert.Equal(t, expectedFn.Pointer(), actualFn.Pointer())
 
 	// all paths should be found (non filtering matches a path)
 	locations, err := resolver.FilesByGlob("**/place")
 	assert.NoError(t, err)
 	// 4: within target/
-	// 1: target/link --> relative path to "place"
+	// 1: target/link --> relative path to "place" // NOTE: this is filtered out since it not unique relative to outside_root/link_target/place
 	// 1: outside_root/link_target/place
-	assert.Len(t, locations, 6)
+	assert.Len(t, locations, 5)
 
 	// ensure that symlink indexing outside of root worked
 	testLocation := "test-fixtures/system_paths/outside_root/link_target/place"
@@ -363,233 +358,65 @@ func Test_isUnallowableFileType(t *testing.T) {
 	tests := []struct {
 		name     string
 		info     os.FileInfo
-		expected bool
+		expected error
 	}{
 		{
 			name: "regular file",
 			info: testFileInfo{
 				mode: 0,
 			},
-			expected: false,
 		},
 		{
 			name: "dir",
 			info: testFileInfo{
 				mode: os.ModeDir,
 			},
-			expected: false,
 		},
 		{
 			name: "symlink",
 			info: testFileInfo{
 				mode: os.ModeSymlink,
 			},
-			expected: false,
 		},
 		{
 			name: "socket",
 			info: testFileInfo{
 				mode: os.ModeSocket,
 			},
-			expected: true,
+			expected: errSkipPath,
 		},
 		{
 			name: "named pipe",
 			info: testFileInfo{
 				mode: os.ModeNamedPipe,
 			},
-			expected: true,
+			expected: errSkipPath,
 		},
 		{
 			name: "char device",
 			info: testFileInfo{
 				mode: os.ModeCharDevice,
 			},
-			expected: true,
+			expected: errSkipPath,
 		},
 		{
 			name: "block device",
 			info: testFileInfo{
 				mode: os.ModeDevice,
 			},
-			expected: true,
+			expected: errSkipPath,
 		},
 		{
 			name: "irregular",
 			info: testFileInfo{
 				mode: os.ModeIrregular,
 			},
-			expected: true,
+			expected: errSkipPath,
 		},
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			assert.Equal(t, test.expected, isUnallowableFileType("dont/care", test.info))
-		})
-	}
-}
-
-func Test_directoryResolver_index(t *testing.T) {
-	// note: this test is testing the effects from newDirectoryResolver, indexTree, and addPathToIndex
-	r, err := newDirectoryResolver("test-fixtures/system_paths/target")
-	if err != nil {
-		t.Fatalf("unable to get indexed dir resolver: %+v", err)
-	}
-	tests := []struct {
-		name string
-		path string
-	}{
-		{
-			name: "has dir",
-			path: "test-fixtures/system_paths/target/home",
-		},
-		{
-			name: "has path",
-			path: "test-fixtures/system_paths/target/home/place",
-		},
-		{
-			name: "has symlink",
-			path: "test-fixtures/system_paths/target/link/a-symlink",
-		},
-		{
-			name: "has symlink target",
-			path: "test-fixtures/system_paths/outside_root/link_target/place",
-		},
-	}
-	for _, test := range tests {
-		t.Run(test.name, func(t *testing.T) {
-			info, err := os.Stat(test.path)
-			assert.NoError(t, err)
-
-			// note: the index uses absolute paths, so assertions MUST keep this in mind
-			cwd, err := os.Getwd()
-			require.NoError(t, err)
-
-			p := file.Path(path.Join(cwd, test.path))
-			assert.Equal(t, true, r.fileTree.HasPath(p))
-			exists, ref, err := r.fileTree.File(p)
-			assert.Equal(t, true, exists)
-			if assert.NoError(t, err) {
-				return
-			}
-			assert.Equal(t, info, r.metadata[ref.ID()])
-		})
-	}
-}
-
-func Test_handleFileAccessErr(t *testing.T) {
-	tests := []struct {
-		name                string
-		input               error
-		expectedPathTracked bool
-	}{
-		{
-			name:                "permission error does not propagate",
-			input:               os.ErrPermission,
-			expectedPathTracked: true,
-		},
-		{
-			name:                "file does not exist error does not propagate",
-			input:               os.ErrNotExist,
-			expectedPathTracked: true,
-		},
-		{
-			name:                "non-permission errors are tracked",
-			input:               os.ErrInvalid,
-			expectedPathTracked: true,
-		},
-		{
-			name:                "non-errors ignored",
-			input:               nil,
-			expectedPathTracked: false,
-		},
-	}
-
-	for _, test := range tests {
-		t.Run(test.name, func(t *testing.T) {
-			r := directoryResolver{
-				errPaths: make(map[string]error),
-			}
-			p := "a/place"
-			assert.Equal(t, r.isFileAccessErr(p, test.input), test.expectedPathTracked)
-			_, exists := r.errPaths[p]
-			assert.Equal(t, test.expectedPathTracked, exists)
-		})
-	}
-}
-
-type indexerMock struct {
-	observedRoots   []string
-	additionalRoots map[string][]string
-}
-
-func (m *indexerMock) indexer(s string, _ *progress.Stage) ([]string, error) {
-	m.observedRoots = append(m.observedRoots, s)
-	return m.additionalRoots[s], nil
-}
-
-func Test_indexAllRoots(t *testing.T) {
-	tests := []struct {
-		name          string
-		root          string
-		mock          indexerMock
-		expectedRoots []string
-	}{
-		{
-			name: "no additional roots",
-			root: "a/place",
-			mock: indexerMock{
-				additionalRoots: make(map[string][]string),
-			},
-			expectedRoots: []string{
-				"a/place",
-			},
-		},
-		{
-			name: "additional roots from a single call",
-			root: "a/place",
-			mock: indexerMock{
-				additionalRoots: map[string][]string{
-					"a/place": {
-						"another/place",
-						"yet-another/place",
-					},
-				},
-			},
-			expectedRoots: []string{
-				"a/place",
-				"another/place",
-				"yet-another/place",
-			},
-		},
-		{
-			name: "additional roots from a multiple calls",
-			root: "a/place",
-			mock: indexerMock{
-				additionalRoots: map[string][]string{
-					"a/place": {
-						"another/place",
-						"yet-another/place",
-					},
-					"yet-another/place": {
-						"a-quiet-place-2",
-						"a-final/place",
-					},
-				},
-			},
-			expectedRoots: []string{
-				"a/place",
-				"another/place",
-				"yet-another/place",
-				"a-quiet-place-2",
-				"a-final/place",
-			},
-		},
-	}
-
-	for _, test := range tests {
-		t.Run(test.name, func(t *testing.T) {
-			assert.NoError(t, indexAllRoots(test.root, test.mock.indexer))
+			assert.Equal(t, test.expected, disallowByFileType("dont/care", test.info, nil))
 		})
 	}
 }
@@ -608,7 +435,7 @@ func Test_directoryResolver_FilesByMIMEType(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(test.fixturePath, func(t *testing.T) {
-			resolver, err := newDirectoryResolver(test.fixturePath)
+			resolver, err := newDirectoryResolver(test.fixturePath, "")
 			assert.NoError(t, err)
 			locations, err := resolver.FilesByMIMEType(test.mimeType)
 			assert.NoError(t, err)
@@ -621,7 +448,7 @@ func Test_directoryResolver_FilesByMIMEType(t *testing.T) {
 }
 
 func Test_IndexingNestedSymLinks(t *testing.T) {
-	resolver, err := newDirectoryResolver("./test-fixtures/symlinks-simple")
+	resolver, err := newDirectoryResolver("./test-fixtures/symlinks-simple", "")
 	require.NoError(t, err)
 
 	// check that we can get the real path
@@ -646,12 +473,12 @@ func Test_IndexingNestedSymLinks(t *testing.T) {
 	// check that we can access the same file via 2 symlinks
 	locations, err = resolver.FilesByGlob("**/link_*")
 	require.NoError(t, err)
-	require.Len(t, locations, 2)
+	require.Len(t, locations, 1) // you would think this is 2, however, they point to the same file, and glob only returns unique files
 
 	// returned locations can be in any order
 	expectedVirtualPaths := []string{
 		"link_to_link_to_new_readme",
-		"link_to_new_readme",
+		//"link_to_new_readme", // we filter out this one because the first symlink resolves to the same file
 	}
 
 	expectedRealPaths := []string{
@@ -670,11 +497,14 @@ func Test_IndexingNestedSymLinks(t *testing.T) {
 }
 
 func Test_IndexingNestedSymLinks_ignoredIndexes(t *testing.T) {
-	filterFn := func(path string, _ os.FileInfo) bool {
-		return strings.HasSuffix(path, string(filepath.Separator)+"readme")
+	filterFn := func(path string, _ os.FileInfo, _ error) error {
+		if strings.HasSuffix(path, string(filepath.Separator)+"readme") {
+			return errSkipPath
+		}
+		return nil
 	}
 
-	resolver, err := newDirectoryResolver("./test-fixtures/symlinks-simple", filterFn)
+	resolver, err := newDirectoryResolver("./test-fixtures/symlinks-simple", "", filterFn)
 	require.NoError(t, err)
 
 	// the path to the real file is PRUNED from the index, so we should NOT expect a location returned
@@ -694,7 +524,7 @@ func Test_IndexingNestedSymLinks_ignoredIndexes(t *testing.T) {
 }
 
 func Test_IndexingNestedSymLinksOutsideOfRoot(t *testing.T) {
-	resolver, err := newDirectoryResolver("./test-fixtures/symlinks-multiple-roots/root")
+	resolver, err := newDirectoryResolver("./test-fixtures/symlinks-multiple-roots/root", "")
 	require.NoError(t, err)
 
 	// check that we can get the real path
@@ -712,7 +542,7 @@ func Test_IndexingNestedSymLinksOutsideOfRoot(t *testing.T) {
 }
 
 func Test_RootViaSymlink(t *testing.T) {
-	resolver, err := newDirectoryResolver("./test-fixtures/symlinked-root/nested/link-root")
+	resolver, err := newDirectoryResolver("./test-fixtures/symlinked-root/nested/link-root", "")
 	require.NoError(t, err)
 
 	locations, err := resolver.FilesByPath("./file1.txt")
@@ -732,6 +562,14 @@ func Test_directoryResolver_FileContentsByLocation(t *testing.T) {
 	cwd, err := os.Getwd()
 	require.NoError(t, err)
 
+	r, err := newDirectoryResolver(".", "")
+	require.NoError(t, err)
+
+	exists, existingPath, err := r.tree.File(file.Path(filepath.Join(cwd, "test-fixtures/image-simple/file-1.txt")))
+	require.True(t, exists)
+	require.NoError(t, err)
+	require.True(t, existingPath.HasReference())
+
 	tests := []struct {
 		name     string
 		location Location
@@ -739,11 +577,9 @@ func Test_directoryResolver_FileContentsByLocation(t *testing.T) {
 		err      bool
 	}{
 		{
-			name: "use file reference for content requests",
-			location: NewLocationFromDirectory("some/place", file.Reference{
-				RealPath: file.Path(filepath.Join(cwd, "test-fixtures/image-simple/file-1.txt")),
-			}),
-			expects: "this file has contents",
+			name:     "use file reference for content requests",
+			location: NewLocationFromDirectory("some/place", *existingPath.Reference),
+			expects:  "this file has contents",
 		},
 		{
 			name:     "error on empty file reference",
@@ -753,8 +589,6 @@ func Test_directoryResolver_FileContentsByLocation(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			r, err := newDirectoryResolver(".")
-			require.NoError(t, err)
 
 			actual, err := r.FileContentsByLocation(test.location)
 			if test.err {
@@ -775,60 +609,54 @@ func Test_directoryResolver_FileContentsByLocation(t *testing.T) {
 func Test_isUnixSystemRuntimePath(t *testing.T) {
 	tests := []struct {
 		path     string
-		expected bool
+		expected error
 	}{
 		{
-			path:     "proc/place",
-			expected: false,
+			path: "proc/place",
 		},
 		{
 			path:     "/proc/place",
-			expected: true,
+			expected: fs.SkipDir,
 		},
 		{
 			path:     "/proc",
-			expected: true,
+			expected: fs.SkipDir,
 		},
 		{
-			path:     "/pro/c",
-			expected: false,
+			path: "/pro/c",
 		},
 		{
-			path:     "/pro",
-			expected: false,
+			path: "/pro",
 		},
 		{
 			path:     "/dev",
-			expected: true,
+			expected: fs.SkipDir,
 		},
 		{
 			path:     "/sys",
-			expected: true,
+			expected: fs.SkipDir,
 		},
 		{
-			path:     "/something/sys",
-			expected: false,
+			path: "/something/sys",
 		},
 	}
 	for _, test := range tests {
 		t.Run(test.path, func(t *testing.T) {
-			assert.Equal(t, test.expected, isUnixSystemRuntimePath(test.path, nil))
+			assert.Equal(t, test.expected, disallowUnixSystemRuntimePath(test.path, nil, nil))
 		})
 	}
 }
 
 func Test_SymlinkLoopWithGlobsShouldResolve(t *testing.T) {
 	test := func(t *testing.T) {
-		resolver, err := newDirectoryResolver("./test-fixtures/symlinks-loop")
+		resolver, err := newDirectoryResolver("./test-fixtures/symlinks-loop", "")
 		require.NoError(t, err)
 
 		locations, err := resolver.FilesByGlob("**/file.target")
 		require.NoError(t, err)
-		// Note: I'm not certain that this behavior is correct, but it is not an infinite loop (which is the point of the test)
-		// - block/loop0/file.target
-		// - devices/loop0/file.target
-		// - devices/loop0/subsystem/loop0/file.target
-		assert.Len(t, locations, 3)
+
+		require.Len(t, locations, 1)
+		assert.Equal(t, "devices/loop0/file.target", locations[0].RealPath)
 	}
 
 	testWithTimeout(t, 5*time.Second, test)
@@ -848,40 +676,404 @@ func testWithTimeout(t *testing.T, timeout time.Duration, test func(*testing.T))
 	}
 }
 
-func Test_IncludeRootPathInIndex(t *testing.T) {
-	filterFn := func(path string, _ os.FileInfo) bool {
-		return path != "/"
+func TestDirectoryResolver_FilesByPath_baseRoot(t *testing.T) {
+	cases := []struct {
+		name     string
+		root     string
+		input    string
+		expected []string
+	}{
+		{
+			name:  "should find the base file",
+			root:  "./test-fixtures/symlinks-base/",
+			input: "./base",
+			expected: []string{
+				"/base",
+			},
+		},
+		{
+			name:  "should follow a link with a pivoted root",
+			root:  "./test-fixtures/symlinks-base/",
+			input: "./foo",
+			expected: []string{
+				"/base",
+			},
+		},
+		{
+			name:  "should follow a relative link with extra parents",
+			root:  "./test-fixtures/symlinks-base/",
+			input: "./bar",
+			expected: []string{
+				"/base",
+			},
+		},
+		{
+			name:  "should follow an absolute link with extra parents",
+			root:  "./test-fixtures/symlinks-base/",
+			input: "./baz",
+			expected: []string{
+				"/base",
+			},
+		},
+		{
+			name:  "should follow an absolute link with extra parents",
+			root:  "./test-fixtures/symlinks-base/",
+			input: "./sub/link",
+			expected: []string{
+				"/sub/item",
+			},
+		},
+		{
+			name:  "should follow chained pivoted link",
+			root:  "./test-fixtures/symlinks-base/",
+			input: "./chain",
+			expected: []string{
+				"/base",
+			},
+		},
+	}
+	for _, c := range cases {
+		t.Run(c.name, func(t *testing.T) {
+			resolver, err := newDirectoryResolver(c.root, c.root)
+			assert.NoError(t, err)
+
+			refs, err := resolver.FilesByPath(c.input)
+			require.NoError(t, err)
+			assert.Len(t, refs, len(c.expected))
+			s := strset.New()
+			for _, actual := range refs {
+				s.Add(actual.RealPath)
+			}
+			assert.ElementsMatch(t, c.expected, s.List())
+		})
 	}
 
-	resolver, err := newDirectoryResolver("/", filterFn)
-	require.NoError(t, err)
-
-	exists, ref, err := resolver.fileTree.File(file.Path("/"))
-	require.NoError(t, err)
-	require.NotNil(t, ref)
-	assert.True(t, exists)
-
-	_, exists = resolver.metadata[ref.ID()]
-	require.True(t, exists)
 }
 
-func TestDirectoryResolver_indexPath(t *testing.T) {
-	// TODO: Ideally we can use an OS abstraction, which would obviate the need for real FS setup.
-	tempFile, err := os.CreateTemp("", "")
-	require.NoError(t, err)
+func Test_directoryResolver_resolvesLinks(t *testing.T) {
+	tests := []struct {
+		name     string
+		runner   func(FileResolver) []Location
+		expected []Location
+	}{
+		{
+			name: "by mimetype",
+			runner: func(resolver FileResolver) []Location {
+				// links should not show up when searching mimetype
+				actualLocations, err := resolver.FilesByMIMEType("text/plain")
+				assert.NoError(t, err)
+				return actualLocations
+			},
+			expected: []Location{
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-1.txt",
+					},
+					//VirtualPath: "file-1.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-3.txt",
+					},
+					//VirtualPath: "file-3.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-2.txt",
+					},
+					//VirtualPath: "file-2.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "parent/file-4.txt",
+					},
+					//VirtualPath: "parent/file-4.txt",
+				},
+			},
+		},
+		{
+			name: "by glob to links",
+			runner: func(resolver FileResolver) []Location {
+				// links are searched, but resolve to the real files
+				// for that reason we need to place **/ in front (which is not the same for other resolvers)
+				actualLocations, err := resolver.FilesByGlob("**/*ink-*")
+				assert.NoError(t, err)
+				return actualLocations
+			},
+			expected: []Location{
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-1.txt",
+					},
+					VirtualPath: "link-1",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-2.txt",
+					},
+					VirtualPath: "link-2",
+				},
+				// we already have this real file path via another link, so only one is returned
+				//{
+				//	Coordinates: Coordinates{
+				//		RealPath: "file-2.txt",
+				//	},
+				//	VirtualPath: "link-indirect",
+				//},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-3.txt",
+					},
+					VirtualPath: "link-within",
+				},
+			},
+		},
+		{
+			name: "by basename",
+			runner: func(resolver FileResolver) []Location {
+				// links are searched, but resolve to the real files
+				actualLocations, err := resolver.FilesByGlob("**/file-2.txt")
+				assert.NoError(t, err)
+				return actualLocations
+			},
+			expected: []Location{
+				// this has two copies in the base image, which overwrites the same location
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-2.txt",
+					},
+					//VirtualPath: "file-2.txt",
+				},
+			},
+		},
+		{
+			name: "by basename glob",
+			runner: func(resolver FileResolver) []Location {
+				// links are searched, but resolve to the real files
+				actualLocations, err := resolver.FilesByGlob("**/file-?.txt")
+				assert.NoError(t, err)
+				return actualLocations
+			},
+			expected: []Location{
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-1.txt",
+					},
+					//VirtualPath: "file-1.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-2.txt",
+					},
+					//VirtualPath: "file-2.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-3.txt",
+					},
+					//VirtualPath: "file-3.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "parent/file-4.txt",
+					},
+					//VirtualPath: "parent/file-4.txt",
+				},
+			},
+		},
+		{
+			name: "by basename glob to links",
+			runner: func(resolver FileResolver) []Location {
+				actualLocations, err := resolver.FilesByGlob("**/link-*")
+				assert.NoError(t, err)
+				return actualLocations
+			},
+			expected: []Location{
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-1.txt",
+					},
+					VirtualPath: "link-1",
+					ref:         file.Reference{RealPath: "file-1.txt"},
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-2.txt",
+					},
+					VirtualPath: "link-2",
+					ref:         file.Reference{RealPath: "file-2.txt"},
+				},
+				// we already have this real file path via another link, so only one is returned
+				//{
+				//	Coordinates: Coordinates{
+				//		RealPath: "file-2.txt",
+				//	},
+				//	VirtualPath: "link-indirect",
+				//	ref:         file.Reference{RealPath: "file-2.txt"},
+				//},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-3.txt",
+					},
+					VirtualPath: "link-within",
+					ref:         file.Reference{RealPath: "file-3.txt"},
+				},
+			},
+		},
+		{
+			name: "by extension",
+			runner: func(resolver FileResolver) []Location {
+				// links are searched, but resolve to the real files
+				actualLocations, err := resolver.FilesByGlob("**/*.txt")
+				assert.NoError(t, err)
+				return actualLocations
+			},
+			expected: []Location{
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-1.txt",
+					},
+					//VirtualPath: "file-1.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-2.txt",
+					},
+					//VirtualPath: "file-2.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-3.txt",
+					},
+					//VirtualPath: "file-3.txt",
+				},
+				{
+					Coordinates: Coordinates{
+						RealPath: "parent/file-4.txt",
+					},
+					//VirtualPath: "parent/file-4.txt",
+				},
+			},
+		},
+		{
+			name: "by path to degree 1 link",
+			runner: func(resolver FileResolver) []Location {
+				// links resolve to the final file
+				actualLocations, err := resolver.FilesByPath("/link-2")
+				assert.NoError(t, err)
+				return actualLocations
+			},
+			expected: []Location{
+				// we have multiple copies across layers
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-2.txt",
+					},
+					VirtualPath: "link-2",
+				},
+			},
+		},
+		{
+			name: "by path to degree 2 link",
+			runner: func(resolver FileResolver) []Location {
+				// multiple links resolves to the final file
+				actualLocations, err := resolver.FilesByPath("/link-indirect")
+				assert.NoError(t, err)
+				return actualLocations
+			},
+			expected: []Location{
+				// we have multiple copies across layers
+				{
+					Coordinates: Coordinates{
+						RealPath: "file-2.txt",
+					},
+					VirtualPath: "link-indirect",
+				},
+			},
+		},
+	}
 
-	resolver, err := newDirectoryResolver(tempFile.Name())
-	require.NoError(t, err)
-
-	t.Run("filtering path with nil os.FileInfo", func(t *testing.T) {
-		// We use one of these prefixes in order to trigger a pathFilterFn
-		filteredPath := unixSystemRuntimePrefixes[0]
-
-		var fileInfo os.FileInfo = nil
-
-		assert.NotPanics(t, func() {
-			_, err := resolver.indexPath(filteredPath, fileInfo, nil)
+	for _, test := range tests {
+		t.Run(test.name, func(t *testing.T) {
+			resolver, err := newDirectoryResolver("./test-fixtures/symlinks-from-image-symlinks-fixture", "")
+			require.NoError(t, err)
 			assert.NoError(t, err)
+
+			actual := test.runner(resolver)
+
+			compareLocations(t, test.expected, actual)
 		})
-	})
+	}
+}
+
+func TestDirectoryResolver_DoNotAddVirtualPathsToTree(t *testing.T) {
+	resolver, err := newDirectoryResolver("./test-fixtures/symlinks-prune-indexing", "")
+	require.NoError(t, err)
+
+	allRealPaths := resolver.tree.AllRealPaths()
+	pathSet := file.NewPathSet(allRealPaths...)
+
+	assert.False(t,
+		pathSet.Contains("/before-path/file.txt"),
+		"symlink destinations should only be indexed at their real path, not through their virtual (symlinked) path",
+	)
+
+	assert.False(t,
+		pathSet.Contains("/a-path/file.txt"),
+		"symlink destinations should only be indexed at their real path, not through their virtual (symlinked) path",
+	)
+
+}
+
+func TestDirectoryResolver_FilesContents_errorOnDirRequest(t *testing.T) {
+	resolver, err := newDirectoryResolver("./test-fixtures/system_paths", "")
+	assert.NoError(t, err)
+
+	var dirLoc *Location
+	for loc := range resolver.AllLocations() {
+		entry, err := resolver.index.Get(loc.ref)
+		require.NoError(t, err)
+		if entry.Metadata.IsDir {
+			dirLoc = &loc
+			break
+		}
+	}
+
+	require.NotNil(t, dirLoc)
+
+	reader, err := resolver.FileContentsByLocation(*dirLoc)
+	require.Error(t, err)
+	require.Nil(t, reader)
+}
+
+func TestDirectoryResolver_AllLocations(t *testing.T) {
+	resolver, err := newDirectoryResolver("./test-fixtures/symlinks-from-image-symlinks-fixture", "")
+	assert.NoError(t, err)
+
+	paths := strset.New()
+	for loc := range resolver.AllLocations() {
+		if strings.HasPrefix(loc.RealPath, "/") {
+			// ignore outside of the fixture root for now
+			continue
+		}
+		paths.Add(loc.RealPath)
+	}
+	expected := []string{
+		"file-1.txt",
+		"file-2.txt",
+		"file-3.txt",
+		"link-1",
+		"link-2",
+		"link-dead",
+		"link-indirect",
+		"link-within",
+		"parent",
+		"parent-link",
+		"parent/file-4.txt",
+	}
+
+	pathsList := paths.List()
+	sort.Strings(pathsList)
+
+	assert.ElementsMatchf(t, expected, pathsList, "expected all paths to be indexed, but found different paths: \n%s", cmp.Diff(expected, paths.List()))
 }
